#
# spec file for package polkit-default-privs
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# icecream 0


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           polkit-default-privs
Version:        13.2+20200421.207b724
Release:        lp152.1.1
Summary:        SUSE PolicyKit default permissions
License:        GPL-2.0-or-later
Group:          Productivity/Security
Source:         polkit-default-privs-%version.tar.xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  polkit
%if 0%{?suse_version} < 1310
Requires:       libmozjs185-1_0
%endif
Requires:       polkit
Supplements:    PolicyKit
Supplements:    libpolkit0, polkit
BuildArch:      noarch
# please open bugreports at bugzilla.suse.com
Url:            http://github.com/openSUSE/polkit-default-privs.git
PreReq:         %fillup_prereq

%description
Predefined polkit profiles for different usage scenarios like desktop and
server. These profiles define the kind of authentication required for various
polkit actions used across applications.


Authors:
--------
    Ludwig Nussel

# use a separate package for the static whitelist (i.e. the one that isn't
# part of the different profile selectable during runtime). This whitelist is
# of no use for users and only needed during rpmlint time.
%package -n polkit-whitelisting
Summary:        Static polkit whitelists for processing by rpmlint-checks
Group:          Productivity/Security

%description -n polkit-whitelisting
This package contains static polkit whitelistings for polkit Java Script rule
files. The whitelistings will be processed by rpmlint-checks to determine
valid rule file installations by other packages.

%prep
%setup -q

%build

%install
make install DESTDIR=$RPM_BUILD_ROOT fillupdir="%{_fillupdir}"
mkdir -p $RPM_BUILD_ROOT/etc/polkit-1/rules.d/
> $RPM_BUILD_ROOT/etc/polkit-1/rules.d/90-default-privs.rules

%post
%{fillup_only -ns security polkit_default_privs}
/sbin/set_polkit_default_privs >/dev/null

%files
%doc README.md
%defattr(-,root,root,-)
%ghost %attr(0644,root,root) /etc/polkit-1/rules.d/90-default-privs.rules
%config /etc/polkit-default-privs.easy
%config /etc/polkit-default-privs.standard
%config /etc/polkit-default-privs.restrictive
%config(noreplace) /etc/polkit-default-privs.local
/sbin/chkstat-polkit
/sbin/set_polkit_default_privs
%_mandir/man*/*
%{_fillupdir}/sysconfig.security-polkit_default_privs

%files -n polkit-whitelisting
%defattr(-,root,root)
/etc/polkit-rules-whitelist.json

%changelog
* Tue Apr 21 2020 matthias.gerstner@suse.com
- Update to version 13.2+20200421.207b724:
  * packagekit: allow system-sources-refresh w/o password entry (bsc#1169540)
* Thu Nov 28 2019 malte.kraus@suse.com
- Update to version 13.2+20191128.c2eb3f7:
  * fix ModemManager1.Time whitelisting (bsc#1156961)
* Fri Nov 22 2019 malte.kraus@suse.com
- Update to version 13.2+20191122.eb9cc80:
  * whitelist org.freedesktop.ModemManager1.Modem.Time (bsc#1156961)
  * kcm_sddm: incremental addition of new rules (bsc#1145182)
* Mon Oct 21 2019 jsegitz@suse.com
- Update to version 13.2+20191015.280c25b:
  * gnome-initial-session: whitelist polkit rules in
    20-gnome-initial-setup.rules (bsc#1125432)
  * Networkd rules whitelisted for package "sytemd-network"
* Thu Sep  5 2019 malte.kraus@suse.com
- Update to version 13.2+20190905.0016c47:
  * whitelist new systemd-resolved actions (bnc#1149216)
* Tue Aug 27 2019 malte.kraus@suse.com
- Update to version 13.2+20190827.0cc2a82:
  * make new systemd rules more restrictive (boo#1146300,
    boo#1145639)
* Fri Aug 23 2019 lnussel@suse.de
- Update to version 13.2+20190823.a5f89c3:
  * systemd-networkd (boo#1146300)
  * systemd-portabled (boo#1145639)
* Tue Aug  6 2019 jsegitz@suse.de
- Update to version 13.2+20190806.841a06b:
  * libvirt polkit actions: Additional no:no:no action (bsc#1144077)
* Thu Aug  1 2019 matthias.gerstner@suse.com
- Update to version 13.2+20190801.f0c6234:
  * calamares: whitelist pkexec run as root in X11 action
  * mousepad: whitelisting of pkexec action (bsc#1143216)
* Thu Jul 11 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190711.953db4f:
  * libvirt: add a couple of additional polkit actions (bsc#1140151)
* Thu Jul  4 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190704.dfb36ad:
  * libvirt rules: fix whitelisting (bsc#1125314)
* Wed Jul  3 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190703.9a076dc:
  * libvirt polkit actions: whitelisting of incremental no:no:no actions (bsc#1140151)
  * backintime-qt: removal of old rule name (bsc#1133680)
* Mon May 27 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190527.64d9813:
  * polkit-rules-whitelist.json: fix syntax error
* Thu May 23 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190523.efe368f:
  * polkit profiles: whitelist lightdm-gtk-greeter-settings (bsc#1135695)
* Mon May 20 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190520.a67a2af:
  * polkit rules: whitelist libvirt (bsc#1125314)
  * rules for systemd org.freedesktop.login1.set-reboot* (bsc#1133843)
* Tue May  7 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190507.75c6d67:
  * fwupd: add one more follow-up rules for bsc#1133082
* Fri May  3 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190503.00651e7:
  * tuned: add new plugin doc actions (bsc#1131858)
* Thu May  2 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190502.37ad64c:
  * fwupd: add incrementally added polkit actions (bsc#1133082)
* Tue Apr 30 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190430.a4836d6:
  * backintime: add renamed gui pkexec action (bsc#1133680)
  * backintime: add restrictive config, too
* Thu Apr 11 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190411.5775d58:
  * gamemode: additional polkit action for gpuclockctl (bsc#1129967)
  * NetworkManager: remove wrongly named wifi-scan rule (bsc#1128560)
* Fri Mar 15 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190315.3da47ba:
  * rules.d whitelist: add systemd-network (bsc#1125438) and flatpak entries (bsc#984817)
* Fri Mar 15 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190315.b904805:
  * polkit privs whitelisting: add renamed wifi-scan -> wifi.scan action (bsc#1128560)
* Wed Mar  6 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190306.b56445c:
  * whitelisting: systemd org.freedesktop.hostname1.get-product-uuid
* Tue Feb 26 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190226.f884108:
  * polkit-rules-whitelist: adjust format to better support follow-up audits
    (bsc#1125314)
* Mon Feb 25 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190225.0ef150d:
  * relax change-own-user-data action in the restrictive profile (bsc#1125110)
* Wed Feb 13 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190213.2f39f9b:
  * add whitelisting file for files installed in polkit-1/rules.d * (bsc#1125314)
  * the new whitelisting is packaged in a separate subpackage, because it is
    not needed for normal operation, only during OBS build time for rpmlint to
    find it.
* Thu Feb  7 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190207.4d86620:
  * add manage-vdo privilege of udisks2 (bsc#1123747)
  * further improve documentation in /etc/polkit-default-privs.local
  * sort the output rules in /etc/polkit-1/rules.d/90-default-privs to
    make the runs reproducible. (https://github.com/openSUSE/polkit-default-privs/issues/3)
* Wed Feb  6 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190207.9bb8655:
  * man pages: extend documentation to better describe syntax and profiles
  * install README.md as part of package documentation
  * set_polkit_default_privs: add warning about unknown profiles
  * introduce a new polkit-default-privs easy profile
* Wed Jan 30 2019 opensuse-packaging@opensuse.org
- Update to version 13.2+20190130.b2262b2:
  * Whitelist additional Flatpak action metadata-update (bsc#1123653)
  * soften authentication requirements for flatpak's appstream-update (bsc#1122116)
* Mon Jan 28 2019 opensuse-packaging@opensuse.org
- whitelist newly introduced network manager wifi-scan action (bsc#1122262)
* Fri Jan 25 2019 bjorn.lie@gmail.com
- Be explicit in service file about master branch is the one in use
  for tarball generation via revision parameter.
* Mon Jan 14 2019 matthias.gerstner@suse.com
- introduce service file for pulling new releases from git upstream instead of
  using the old mkchanges script from the git repo (bsc#1121841). This changes
  the version number of the package but nothing else.
* Thu Jan  3 2019 matthias.gerstner@suse.com
- luckybackup: initial whitelisting of polkit pkexec action (bsc#1120403)
* Fri Dec 21 2018 matthias.gerstner@suse.com
- boltd: initial whitelisting of polkit actions (bsc#1119975)
* Tue Dec 11 2018 matthias.gerstner@suse.com
- tuned: add new logging actions (bsc#1118117)
* Tue Nov 27 2018 matthias.gerstner@suse.com
- chkstat: adjust DO NOT EDIT banner in generated rules file (bsc#1099754)
* Thu Nov 15 2018 matthias.gerstner@suse.com
- spice-gtk: relax lowlevelusbaccess requirements (bsc#1083025). Users already
  need to be in the kvm group to access the setuid binary anyways.
* Thu Nov 15 2018 matthias.gerstner@suse.com
- blueman: relax standard profile rules, drop unneeded bluez.config rule (bsc#1083066)
* Wed Sep  5 2018 matthias.gerstner@suse.com
- polkit-default-privs: add renamed libvirt rules (bsc#1106813)
* Thu Aug  9 2018 matthias.gerstner@suse.com
- polkit-default-privs: add meson install action (bsc#1103811)
* Wed Aug  8 2018 matthias.gerstner@suse.com
- polkit-default-privs: fix syntax error in gamemode whitelisting (bsc#1104135)
* Mon Jul 30 2018 matthias.gerstner@suse.com
- polkit-default-privs: whitelist gamemode pkexec action (bsc#1093979)
* Fri Jul 27 2018 matthias.gerstner@suse.com
- polkit-default-privs: fix switchboard-plug* whitelisting. An error slipped
  in that causes `set_polkit_default_privs` to print an error message.
* Fri Jul  6 2018 matthias.gerstner@suse.com
- polkit-default-privs: whitelist incremental libvirt actions (bnc#1100328)
- polkit-default-privs: group together the large blocks of libvirt rules
* Thu Jul  5 2018 matthias.gerstner@suse.com
- polkit-default-privs: whitelist switchboard-plug-* (bsc#1088472)
* Fri Jun 22 2018 matthias.gerstner@suse.com
- polkit-default-privs: add cinnamon-control-center datetime action (bnc#1090371)
* Thu Jun 21 2018 matthias.gerstner@suse.com
- polkit-default-privs: add lightdm rules (bnc#1089436)
* Wed Jun 13 2018 matthias.gerstner@suse.com
- polkit-default-privs: added liblxqt backlight action (bnc#1092192)
* Tue Jun 12 2018 matthias.gerstner@suse.com
- polkit-default-privs: whitelisting new resolve1 action of systemd (bnc#1096907)
- polkit-default-privs: harmonized systemd comments a bit
* Thu Jun  7 2018 matthias.gerstner@suse.com
- polkit-default-privs: new action change-own-password for accountsservice (bnc#1088780)
* Tue Apr 24 2018 matthias.gerstner@suse.com
- polkit-default-privs: whitelisting renamed kalarm polkit actions (bnc#1087714)
* Wed Apr 11 2018 matthias.gerstner@suse.com
- polkit-default-privs: additional tuned rules (bnc#1088648)
* Wed Mar 28 2018 matthias.gerstner@suse.com
- polkit-default-privs: some more amnesty whitelisting of untracked
  privileges. Two more packages are affected:
  - bleachbit (bsc#1087326)
  - systemd, systemd-mini (bsc#1087328)
* Mon Mar 12 2018 matthias.gerstner@suse.com
- polkit-default-privs: mass amnesty whitelisting of untracked privileges. See
  https://lists.opensuse.org/opensuse-factory/2018-02/msg01044.html for
  rationale. This allows existing packages in Factory to continue building
  after the tighter rpmlint-Factory checks become effective. Following
  packages are affected:
  - blueman (bsc#1083066)
  - cinnamon settings-daemon (bnc#1083067)
  - connman (bsc#1083069)
  - flatpak (bsc#984817)
  - fwupd (bsc#1083022)
  - gsmartcontrol (bsc#1084693)
  - gvfs (bsc#1073214)
  - laptop-mode-tools (bsc#1084695)
  - mate-system-monitor (bsc#1084701)
  - nemo (bsc#1084702)
  - nemo-extensions (bsc#1084703)
  - PackageKit (bnc#993505)
  - pantheon-files (bsc#1084704)
  - scap-workbench (bsc#1084706)
  - spice-gtk (bsc#1083025)
  - sysprof (bsc#1083055)
* Wed Jan 31 2018 krahmer@suse.com
- polkit-default-privs: adding more NM actions (bsc#1077504)
* Wed Jan 17 2018 krahmer@suse.com
- polkit-default-privs: adding new udisks2 rules (bsc#1073216)
* Mon Dec 18 2017 matthias.gerstner@suse.com
- polkit-default-privs: added connectivity-check for NetworkManager (bnc#1072702)
* Wed Nov 29 2017 krahmer@suse.com
- polkit-default-privs: adding new sddm kcm actions (bsc#1065563)
* Fri Nov 24 2017 matthias.gerstner@suse.com
- Fixed usage of %%_fillupdir macro, needs to be passed to `make install` such
  that the file is installed into the right location.
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Oct 25 2017 krahmer@suse.com
- polkit-default-privs: adding flatpak (bsc#1064011)
- polkit-default-privs: adding connman (bsc#1057697)
* Wed Oct 11 2017 krahmer@suse.com
- polkit-default-privs: adding deja-dup (bsc#1058935)
* Wed Sep  6 2017 krahmer@suse.com
- polkit-default-privs: adding fwupd (bsc#932807)
* Wed Aug 23 2017 krahmer@suse.com
- adding more flatpak rules (bsc#1012961)
* Fri Jul 21 2017 matthias.gerstner@suse.com
- Added new tuned method verify_profile_ignore_missing (bnc#1048961)
* Wed Jul 19 2017 krahmer@suse.com
- polkit-default-privs: adding new realmd action (bsc#1048025)
* Mon Jul  3 2017 krahmer@suse.com
- polkit-default-privs: adjusting brltty (bsc#967436)
* Tue Jun 20 2017 krahmer@suse.com
- relaxing action "org.opensuse.cupspkhelper.mechanism.job-edit" (bsc#827331)
* Fri Apr 28 2017 matthias.gerstner@suse.com
- added polkit rules for backintime (bnc#1007723, bnc#1032717)
- relaxing powerdevil rules (bsc#1026038)
* Tue Apr 11 2017 matthias.gerstner@suse.com
- added polkit rules for renamed kcmwallet -> kcmwallet5 (bsc#1033296)
* Tue Apr 11 2017 matthias.gerstner@suse.com
- added polkit rules for tuned (bsc#1007279)
* Mon Feb  6 2017 krahmer@suse.com
- polkit-default-privs: adding blueman actions (bsc#987141)
* Mon Jan 30 2017 krahmer@suse.com
- adding kde powerdevil gpu helper (bsc#1019644)
* Tue Dec  6 2016 krahmer@suse.com
- adding org.freedesktop.login1.set-self-linger (bsc#1009468)
* Tue Oct 11 2016 meissner@suse.com
- add flatpak privileges, but currently auth_admin currently (bsc#984817)
* Mon Sep 12 2016 krahmer@suse.com
- polkit-default-privs: cleanups as per discussion with Ludwig
- polkit-default-privs: adding rules for sysprof (bsc#996111) and networkmanager (bsc#996110)
* Mon Jun 13 2016 krahmer@suse.com
- polkit-default-privs: adding ModemManager (bsc#976945)
* Wed Apr 13 2016 krahmer@suse.com
- added brltty (bsc#967436)
* Mon Apr 11 2016 meissner@suse.com
- add importd privs as default tracked (bsc#964935)
* Tue Mar 22 2016 krahmer@suse.com
- polkit-default-privs: relaxing firewalld polkit rule for desktop (bsc#971580)
* Tue Jan  5 2016 krahmer@suse.com
- polkit-default-privs: adding libvirt action ids (bsc#959297)
* Tue Dec  1 2015 krahmer@suse.com
- polkit-default-privs: Adding new systemd actions (bsc#955626)
- polkit-default-privs: create files with consistent permissions
* Mon Nov  9 2015 krahmer@suse.com
- polkit-default-privs: adding rules for cinnamon settings-daemon (bsc#951830)
- polkit-default-privs: relaxing some ModemManager rules to avoid typing password after screenlock/hibernate (bsc#948728)
* Tue Jun 23 2015 krahmer@suse.com
- polkit-default-privs: PackageKit (bnc#929212)
* Mon Jun  8 2015 krahmer@suse.com
- polkit-default-privs: adding netvisix rules (bsc#930195)
* Fri May 22 2015 meissner@suse.com
- instead of auth-admin, disallow colord management for inactive and
  other users, so they do not get root password popups bsc#918594
* Wed Apr 22 2015 krahmer@suse.com
- polkit-default-privs: adding gnome-control-center actions (bnc#927508)
    adding realmd actions (bnc#916767)
* Mon Apr 20 2015 krahmer@suse.com
- polkit-default-privs: rename of powerdevil action-names (bnc#927275)
* Wed Apr  8 2015 krahmer@suse.com
- polkit-default-privs: add urfkill (bnc#926288) polkit action
* Tue Apr  7 2015 krahmer@suse.com
- polkit-default-privs: added gnome-multi-writer actions (bnc#924062)
* Wed Feb 11 2015 krahmer@suse.com
- adding storaged rules (bnc#915770)
* Wed Jan 14 2015 krahmer@suse.com
- adding KDE5 powerdevil rules (bnc#912121)
* Wed Dec 10 2014 krahmer@suse.com
- added firewalld (bnc#907625) polkit actions
* Fri Nov 28 2014 krahmer@suse.com
- polkit-default-privs: adding _keep to ModemManager rules (bnc#900813)
* Fri Nov  7 2014 meissner@suse.com
- Add org.kde.kcontrol.kcmsddm.save (bsc#904313)
* Mon Nov  3 2014 krahmer@suse.com
- polkit-default-privs: relaxing pcsc rules (bsc#864178)
* Mon Sep 29 2014 krahmer@suse.com
- polkit-default-privs: Addings missing rules for restrictive mode (bnc#898001)
* Wed Aug  6 2014 krahmer@suse.com
- polkit-defaultprivs: relaxing rules for SLE12 create-profile in colord (bnc#887511)
* Tue Jul 15 2014 krahmer@suse.com
- relaxing fprintd rules (bnc#850807)
* Fri Jul 11 2014 meissner@suse.com
- replace SuSEconfig mentioning by correct script name (bnc#886809)
* Mon May 19 2014 meissner@suse.com
- tentatively allow new org.selinux helper interfaces in policycoreutils (bnc#878631)
- polkit-default-privs: adding pcsc-lite rules (bnc#864178)
* Wed Apr 16 2014 meissner@suse.com
- change org.kde.fontinst.manage to auth_admin_keep (bnc#704805)
* Wed Apr 16 2014 meissner@suse.com
- adding org.kde.baloo.filewatch.raiselimit action (bnc#866131)
* Mon Mar 24 2014 krahmer@suse.com
- polkit-default-privs: relaxing
  org.freedesktop.color-manager.create-device   and
  org.freedesktop.color-manager.delete-device, its basically just a DB
  operation and colord checks the owner of delete id is the same as
  the creator (bnc#861076)
* Wed Mar 12 2014 meissner@suse.com
- backlight helpers: relaxing rules in restrictive mode,
  otherwise we get popups requesting LED state changes
  bnc#866806
* Wed Nov 20 2013 krahmer@suse.com
- Adding kwallet polkit rules (bnc#849739)
* Tue Nov 19 2013 meissner@suse.com
- new version is 13.2
* Tue Nov 19 2013 krahmer@suse.com
- adding policycoreutils rules (bnc#848550)
* Tue Oct 29 2013 meissner@suse.com
- git repo moved to https://github.com/openSUSE/polkit-default-privs
* Wed Oct 23 2013 meissner@suse.com
- disable system source refresh on inactive console to avoid annoying popups bnc#834165
* Wed Aug 28 2013 meissner@suse.com
- allow org.mate.power.backlight-helper on standard (bnc#831404)
- track gufw
- add org.mate.randr.install-system-wide auth_admin_keep (bnc#831404)
- track mate-settings-daemons privileges (bnc#831404)
* Wed Jul 10 2013 meissner@suse.com
- added polkit-default-privs temporary permissions until audited bnc#827644
* Fri Jul  5 2013 dimstar@opensuse.org
- Only require libmozjs185-1_0 on openSUSE up to 12.3:
  + On openSUSE 13.1, we use libmozjs-17_0
  + Since polkit 0.111, the mozjs library parser is no longer
    optional. For this reason, we also do not have to worry to
    Require the correct library in this case anymore.
* Thu Jul  4 2013 meissner@suse.com
- added powerdevil privs (bnc#825256)
* Fri Jun 28 2013 meissner@suse.com
- Added gnome-settings-daemon new policy
  org.gnome.settings-daemon.plugins.wacom.wacom-oled-helper (bnc#822405)
* Mon Jun 17 2013 meissner@suse.com
- track nepomuk rights (bnc#825262)
* Fri Jun 14 2013 meissner@suse.com
- gnome-system-monitor: track its permissions as they are found (bnc#822011)
* Tue Jun 11 2013 meissner@suse.com
- added lightdm-kde-greeter (bnc#794705)
* Tue Jun  4 2013 meissner@suse.com
- allow fprintd polkit privileges (bnc#792095)
* Mon Apr 15 2013 meissner@suse.com
- ModemManager 0.8 with org.freedesktop.ModemManager1 interface added (a bit more relaxed than the old interface) bnc#798273
- 13.1 is next opensuse
* Wed Apr  3 2013 meissner@suse.com
- bump version for next openSUSE release.
* Wed Apr  3 2013 meissner@suse.com
- allow org.freedesktop.packagekit.trigger-offline-update and org.freedesktop.packagekit.clear-offline-update in standard same way as normal patch update (bnc#798885 bnc#812504)
* Wed Mar 27 2013 meissner@suse.com
- added new udisks2 privileges (bnc#809277)
* Fri Mar 22 2013 meissner@suse.com
- add org.opensuse.policykit.gparted auth_admin (bnc#810888)
* Sun Mar 10 2013 hrvoje.senjan@gmail.com
- Default rules are moved to '90', so own them as '90' instead '50'
* Tue Mar  5 2013 lnussel@suse.de
- move default rules to '90', bnc#807097
* Wed Feb 27 2013 lnussel@suse.de
- add /etc/polkit-1/rules.d/50-default-privs.rules as ghost so it
  gets associated with the package
* Wed Feb 27 2013 lnussel@suse.de
- require ibmozjs185-1_0 as polkit won't apply the policy without it
  (bnc#804376)
* Tue Feb 26 2013 lnussel@suse.de
- set logind inhibit policies to upstream defaults (bnc#804376)
- more elaborate --check-override option
* Mon Feb 25 2013 lnussel@suse.de
- add some debugging capabilities in generated code
* Sat Feb 23 2013 coolo@suse.com
- do not own the polkit directories (with different user, creating
  conflict), but buildrequire polkit
* Thu Feb 21 2013 lnussel@suse.de
- fix restrictive privileges
- generate javascript files for new polkit (bnc#804376)
- implement check for overrides
* Tue Feb 19 2013 meissner@suse.com
- whitelist PackageKit / systemd offline update permissions, currently admin only
- more systemd allows to make rpmlint happier bnc#783897
* Fri Nov  2 2012 meissner@suse.com
- new systemd privileges, mostly allowing applications to inhibit system actions (bnc#783897)
* Wed Oct 24 2012 meissner@suse.com
- added polkit default privs for GNOME control-center (bnc#779938)
* Tue Oct 23 2012 meissner@suse.com
- added new udisks2 policykit privileges at lowest setting bnc#779404
* Tue Oct 16 2012 meissner@suse.com
- 12.3 is next opensuse
* Tue Oct 16 2012 meissner@suse.com
- allow realtimekit at desktop permission (bnc#753849)
- fixed typo
* Thu Jul 12 2012 meissner@suse.com
- allow logged in users to update the system via online updates. bnc#771189
* Thu Jul  5 2012 meissner@suse.com
- relax colord after auditing (bnc#698250)
* Tue Jun  5 2012 lnussel@suse.de
- fix script name in sysconfig file (bnc#765227)
* Tue May 15 2012 lnussel@suse.de
- add more udisks2 privileges (bnc#761872)
* Thu Mar 29 2012 lnussel@suse.de
- add org.kde.recorditnow.helper.watch (bnc#753908)
- add org.gnome.settings-daemon.plugins.wacom.wacom-led-helper (bnc#750795)
* Wed Feb 29 2012 lnussel@suse.de
- add smb4k (bnc#749065)
* Wed Feb 29 2012 lnussel@suse.de
- add udisks2 (bnc#742751)
* Wed Jan 18 2012 lnussel@suse.de
- add org.freedesktop.packagekit.repair-system (bnc#742024)
- fix FSF address
- remove old obsoletes
* Thu Dec  1 2011 lnussel@suse.de
- add org.opensuse.yast.system.terminal.read
* Wed Nov 23 2011 lnussel@suse.de
- set version to 12.2
- remove obsolete moblin privileges
- allow org.freedesktop.ModemManager.Device.Control (bnc#732358)
- allow setting the system's time zone (bnc#731812)
* Wed Nov 23 2011 lnussel@suse.de
- change NetworkManager policies (bnc#716291)
* Fri Oct 28 2011 lnussel@suse.de
- fix logind privileges to be consistend with consolekit (bnc#726969)
* Wed Oct 26 2011 lnussel@suse.de
- set org.freedesktop.accounts.change-own-user-data to yes (bnc#676638)
* Tue Aug 23 2011 lnussel@suse.de
- rename gnome backlight-helper privilege (bnc#712841)
* Fri Aug  5 2011 lnussel@suse.de
- add org.kde.kalarmrtcwake.settimer (bnc#707723)
* Thu Jul 28 2011 lnussel@suse.de
- set NetworkManager.settings.modify.{own,system} to auth_admin_keep
  so it's less annoying (bnc#680140)
- silence %%post  (bnc#679336)
* Thu Jul 28 2011 lnussel@suse.de
- more sytemd/logind privileges (bnc#641924)
* Wed Jul 27 2011 lnussel@suse.de
- change inactive backlight helper privileges to 'no' (bnc#708639)
- remove hal privileges
* Thu Jul 21 2011 lnussel@suse.de
- change version to 12.1 to show that the package is tied to the
  distro
- set org.freedesktop.accounts.user-administration to auth_admin_keep
* Thu Jul 14 2011 lnussel@suse.de
- add more systemd privileges (bnc#705677)
* Thu Jul  7 2011 lnussel@suse.de
- set org.gnome.gconf.defaults.* to auth_admin_keep (bnc#703582)
* Thu Jun 16 2011 lnussel@suse.de
- add colord (bnc#698250)
* Mon May 16 2011 lnussel@suse.de
- webyast shutdown privs (bnc#687807)
* Thu May  5 2011 lnussel@suse.de
- add org.freedesktop.ModemManager.USSD (bnc#691896)
* Thu May  5 2011 lnussel@suse.de
- more systemd stuff (bnc#641924)
* Mon May  2 2011 lnussel@suse.de
- add NetworkManager.settings.modify.hostname (bnc#680140)
- add account services (bnc#676638)
- add org.opensuse.cupspkhelper.mechanism.all-edit (bnc#691014)
* Thu Apr 28 2011 lnussel@suse.de
- new gnome-settings-daemon settings (bnc#690496)
* Tue Apr 26 2011 lnussel@suse.de
- add urfkill (bnc#688328)
* Wed Mar 16 2011 lnussel@suse.de
- add some new NetworkManager privileges (bnc#680140)
* Mon Mar  7 2011 lnussel@suse.de
- allow org.freedesktop.ModemManager.Device.Info for active user
  (bnc#674022)
* Tue Feb 15 2011 lnussel@suse.de
- add kde backlight helper (bnc#672145)
* Tue Feb 15 2011 lnussel@suse.de
- add webyast network module (bnc#660981)
* Mon Feb 14 2011 lnussel@suse.de
- more webyast
* Tue Feb  8 2011 lnussel@suse.de
- add webyast-base-ws (bnc#660981)
* Tue Feb  8 2011 lnussel@suse.de
- don't set PolicyKit privileges if PolicyKit isn't installed (bnc#670155)
* Wed Jan 26 2011 lnussel@suse.de
- allow setting the backlight without authentication (bnc#650401)
* Fri Jan 21 2011 lnussel@suse.de
- add xfce4-power-manager (bnc#665169)
* Wed Dec 15 2010 lnussel@suse.de
- add org.freedesktop.packagekit.upgrade-system (bnc#659384)
* Wed Nov 24 2010 lnussel@suse.de
- add policies that appeared in Factory
* Tue Oct 19 2010 lnussel@suse.de
- add policies that appeared in Factory
* Tue Sep 21 2010 lnussel@suse.de
- use unix-group instead of unix-user for polkit-1 overrides (bnc#544579)
* Fri Aug  6 2010 lnussel@suse.de
- add org.kde.kcontrol.kcmkdm
- change org.gnome.clockapplet.mechanism
  - > org.gnome.settingsdaemon.datetimemechanism (bnc#629096)
* Thu Jun 17 2010 lnussel@suse.de
- change org.opensuse.cupspkhelper.mechanism.* to auth_admin_keep (bnc#614779)
* Tue Apr  6 2010 lnussel@suse.de
- add policies that appeared in Factory
* Thu Apr  1 2010 lnussel@suse.de
- add policies that appeared in Factory
- remove PolicyKit requirement
* Fri Mar 26 2010 lnussel@suse.de
- add policies that appeared in Factory
* Thu Feb 25 2010 lnussel@suse.de
- add policies that appeared in Factory
* Thu Oct 22 2009 lnussel@suse.de
- allow users to set the drive spindown time (bnc#548858)
* Tue Oct  6 2009 lnussel@suse.de
- add YaST privileges from Factory
- add org.freedesktop.devicekit.disks.drive-set-spindown which
  appeared in Factory. Sounds potentially dangerous so auth_admin.
* Wed Sep 23 2009 lnussel@suse.de
- own directories in /var (bnc#541258)
* Fri Aug 28 2009 lnussel@suse.de
- polkit-1 support
- add new policies from Factory
* Thu Jan 29 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Dec 11 2008 lnussel@suse.de
- PreReq on PolicyKit to avoid errors from %%post
* Thu Dec 11 2008 lnussel@suse.de
- add privileges silently indroduced by new hal:
    org.freedesktop.hal.device-access.removable-block
    org.freedesktop.hal.leds.brightness
* Tue Nov 25 2008 lnussel@suse.de
- add missing cupspkhelper privileges
* Thu Nov 20 2008 lnussel@suse.de
- com.google.code.backupmanager.schedule -> org.opensuse.backupmanager.schedule
* Tue Nov  4 2008 lnussel@suse.de
- correct comment for POLKIT_DEFAULT_PRIVS (bnc#441300)
* Tue Oct 28 2008 lnussel@suse.de
- add system-config-printer and a few more hal device access lines
* Mon Oct 27 2008 lnussel@suse.de
- combine privilege settings from multiple files (bnc#439127)
* Fri Oct 24 2008 lnussel@suse.de
- fix some wrong privilege settings (bnc#435776)
  * smpppd.connect, system-update and settimezone in restrictive
  * settimezone in standard
* Mon Oct  6 2008 dmueller@suse.de
- obsolete resmgr and hal-resmgr for openSUSE 11.1 and newer
* Wed Sep 17 2008 lnussel@suse.de
- add manpages
- do not use SuSEconfig
* Tue Sep 16 2008 lnussel@suse.de
- add COPYING file (bnc#425444)
- add privilege for backup-manager
* Thu Sep 11 2008 lnussel@suse.de
- allow setting the sytem timezone and installing updates by default
- add smpppd
* Thu Sep  4 2008 lnussel@suse.de
- rename to polkit-default-privs
- add sysconfig files
- default levels are "standard" and "restrictive"
* Tue Aug 19 2008 lnussel@suse.de
- add device access, consolekit, packagekit.set-proxy
* Fri Jun 20 2008 lnussel@suse.de
- add program to list permissions that are missing
- add a few more programs that have permissions
* Wed Jun 18 2008 lnussel@suse.de
- fix easy permissions
- print message when changing permissions
- add libvirt
* Thu Jun 12 2008 lnussel@suse.de
- fix SuSEconfig.polkit-permissions
* Thu Jun 12 2008 lnussel@suse.de
- initial package
